/* phylo.c -- find clock output entries that are phylogenetically consistent,
*  i.e.,
*  1. remove any containing 'n' (for not agreeing with either human or
*  	elephant
*  2. require that no 'e' precede an  'h'
*  3. required that the first e immediately follow the last h according to the
*     following groupings:
*	species 0: human
*	species 1: chimp
*	species 2: rhesus
*	species 3: galago
*	species 4: tree shrew
*	species 5-8: glires
*	species 9-14: laurasiatheres
*	species 15-17: atlantogenata
*  The number of indels assigned to each category is written.
*/

#include "lib.h"

char *human[1000], *chimp[1000], *rhesus[1000], *galago[1000],
  *tree_shrew[1000], *mouse[1000], *dog[1000];
int n_human, n_chimp, n_rhesus, n_galago, n_tree_shrew, n_mouse, n_dog;

void do_print(char **s, int n, char *clade) {
	int i;

	printf("%d %s\n", n, clade);
	for (i = 0; i < n; ++i)
		printf("%s", s[i]);
	putchar('\n');
}

int main(int argc, char **argv) {
	FILE *fp;
	char buf[500], s[100];
	int last_h, first_e, bad = 0, n;
	float f;

	if (argc != 2)
		fatal("arg = new_clock.txt");
	fp = ckopen(argv[1], "r");
	while (fgets(buf, 500, fp)) {
		if (sscanf(buf, "%s", s) != 1 ||
		    strchr(s, 'n') != NULL)
			continue;
		for (first_e = 0; first_e <= 17 && s[first_e] != 'e'; ++first_e)
			;
		for (last_h = 17; last_h >= 0 && s[last_h] != 'h'; --last_h)
			;
		if (last_h > first_e)
			continue;
		if (last_h == 0 && first_e == 1)
			human[n_human++] = copy_string(buf);
		else if (last_h == 1 && first_e == 2)
			chimp[n_chimp++] = copy_string(buf);
		else if (last_h == 2 && first_e == 3)
			rhesus[n_rhesus++] = copy_string(buf);
		else if (last_h == 3 && first_e == 4)
			galago[n_galago++] = copy_string(buf);
		else if (last_h == 4 && first_e < 9)
			tree_shrew[n_tree_shrew++] = copy_string(buf);
		else if (last_h >= 5 && last_h < 9 &&
		         first_e >= 9 && first_e < 15)
			mouse[n_mouse++] = copy_string(buf);
		else if (last_h >= 9 && last_h < 15 && first_e >= 15)
			dog[n_dog++] = copy_string(buf);
		else {
			++bad;
			fprintf(stderr, "%s", buf);
		}
	}
	n = n_human + n_chimp + n_rhesus + n_galago + n_tree_shrew +
	    n_mouse + n_dog;
	f = (float)n;
	printf("%6.4f human, %6.4f chimp, %6.4f rhesus, %6.4f galago, ",
	  (float)n_human/f, (float)n_chimp/f, (float)n_rhesus/f,
	  (float)n_galago/f);
	printf("%6.4f tree_shrew\n%6.4f mouse, %6.4f dog\n",
	  (float)n_tree_shrew/f, (float)n_mouse/f, (float)n_dog/f);
	do_print(human, n_human, "human");
	do_print(chimp, n_chimp, "chimp");
	do_print(rhesus, n_rhesus, "rhesus");
	do_print(galago, n_galago, "galago");
	do_print(tree_shrew, n_tree_shrew, "tree_shrew");
	do_print(mouse, n_mouse, "mouse");
	do_print(dog, n_dog, "dog");

	fprintf(stderr, "%d good, %d bad\n", n, bad);

	return 0;
}
